[Bf-blender-cvs] [83d18a2a91] master: Cycles: Make it more clear message why curve motion attribute was removed

Sergey Sharybin noreply at git.blender.org
Thu Jan 12 18:27:22 CET 2017


Commit: 83d18a2a918964a1a587bb2d4795ec9cc6b8de53
Author: Sergey Sharybin
Date:   Thu Jan 12 15:22:41 2017 +0100
Branches: master
https://developer.blender.org/rB83d18a2a918964a1a587bb2d4795ec9cc6b8de53

Cycles: Make it more clear message why curve motion attribute was removed

===================================================================

M	intern/cycles/blender/blender_curves.cpp

===================================================================

diff --git a/intern/cycles/blender/blender_curves.cpp b/intern/cycles/blender/blender_curves.cpp
index 378ae67f0c..30bacc007b 100644
--- a/intern/cycles/blender/blender_curves.cpp
+++ b/intern/cycles/blender/blender_curves.cpp
@@ -677,8 +677,13 @@ static void ExportCurveSegmentsMotion(Mesh *mesh, ParticleCurveData *CData, int
 	/* in case of new attribute, we verify if there really was any motion */
 	if(new_attribute) {
 		if(i != numkeys || !have_motion) {
-			/* no motion, remove attributes again */
-			VLOG(1) << "No motion, removing attribute";
+			/* No motion or hair "topology" changed, remove attributes again. */
+			if(i != numkeys) {
+				VLOG(1) << "Hair topology changed, removing attribute.";
+			}
+			else {
+				VLOG(1) << "No motion, removing attribute.";
+			}
 			mesh->curve_attributes.remove(ATTR_STD_MOTION_VERTEX_POSITION);
 		}
 		else if(time_index > 0) {




More information about the Bf-blender-cvs mailing list